@@ -78,7 +78,7 @@ private:
   void save(Type type, TQWidget *widget) {
     switch (type.data().defValue.type()) {
       case TQVariant::Bool:
-        writeConfigEntry(type, TQVariant(static_cast<TQCheckBox *>(widget)->isChecked(), 0));
+        writeConfigEntry(type, TQVariant(static_cast<TQCheckBox *>(widget)->isChecked()));
         break;
       default: Q_ASSERT(false); break;
     }
