@@ -9,6 +9,6 @@
 #include "debug_config.h"
 
 const Debugger::Config::Data Debugger::Config::DATA[Nb_Types] = {
-  { "only_stop_on_source_line", I18N_NOOP("Only stop stepping on source line."), TQVariant(true, 0) },
-  { "only_stop_on_project_source_line", I18N_NOOP("Only stop stepping on project source line."), TQVariant(true, 0) }
+  { "only_stop_on_source_line", I18N_NOOP("Only stop stepping on source line."), TQVariant(true) },
+  { "only_stop_on_project_source_line", I18N_NOOP("Only stop stepping on project source line."), TQVariant(true) }
 };
