@@ -7,7 +7,7 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 #ifndef TBL_BOOTLOADER_UI_H
-#define TBL8BOOTLOADER_UI_H
+#define TBL_BOOTLOADER_UI_H
 
 #include <kcombobox.h>
 #include <knuminput.h>
@@ -20,7 +20,7 @@ namespace TinyBootloader
 class ConfigWidget: public ::Programmer::ConfigWidget
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
   ConfigWidget(const ::Programmer::Group &group, TQWidget *parent);
   virtual void loadConfig();
